@@ -4,6 +4,7 @@
 #include <QPointer>
 #include <QDomDocument>
 #include <QObject>
+#include <QGraphicsView>
 #include "paper.h"
 #include "storage.h"
 #include "pageentity.h"
@@ -37,7 +38,7 @@ public:
 
     void newPage(int bookId);
     bool load(int pageId);
-    bool save(Paper *paper);
+    bool save(Paper *paper,QRect source);
     void clear();
     void remove();
 
