@@ -29,6 +29,9 @@ public:
 
     Drawpad* drawpad();
 
+    void setBackgroundColor(QColor val);
+    QColor backgroundColor();
+
 signals:
     void saved(int pageId);
     void deleted(int pageId);
@@ -36,13 +39,18 @@ signals:
 protected:
     void changeEvent(QEvent *e);
     virtual void closeEvent ( QCloseEvent * event );
+    virtual void showEvent(QShowEvent *event);
 
 private:
+    void setMenuVisible(bool val);
     void setCenter();
 
     Ui::PageEditorWindow *ui;
     StandardPage *m_page;
 
+    /// The last selected background color
+    QColor m_backgroundColor;
+
     /// The expected viewport size of QGraphicsView object
     /**
       @remarks It may be different the real size if ui->view
@@ -50,6 +58,7 @@ private:
     QSize viewportSize;
 
 private slots:
+    void on_actionBackground_triggered();
     void on_actionExport_triggered();
     void on_actionDelete_triggered();
 };
