@@ -1,3 +1,6 @@
+/**
+  @author Ben Lau <xbenlau@gmail.com>
+ */
 #ifndef MAEMO5COLORDIALOG_H
 #define MAEMO5COLORDIALOG_H
 
@@ -22,6 +25,7 @@ protected:
     void changeEvent(QEvent *e);
 
 private slots:
+    void on_randomButton_clicked();
     void on_doneButton_clicked();
     void updateColor();
 private:
