@@ -1,3 +1,6 @@
+/**
+  @author Ben Lau <xbenlau@gmail.com>
+ */
 #ifndef MAEMO5COLORHPICKER_H
 #define MAEMO5COLORHPICKER_H
 
