@@ -15,12 +15,14 @@ void appendTestCase(QList<QObject*> &testCases , QObject *parent = 0){
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+    a.setApplicationName("penpen");
 
     qsrand(time(0));
 
     QList<QObject*> testCases;
 
     appendTestCase<BasicUnitTests>(testCases);
+    appendTestCase<StorageUnitTests>(testCases);
 
     QObject *object;
     bool error = false;
